API
===

.. currentmodule:: roiextract.filter

.. autosummary::
   :toctree: generated

   SpatialFilter
   apply_batch


.. currentmodule:: roiextract.optimize

.. autosummary::
   :toctree: generated

   ctf_optimize
